@@ -32,7 +32,14 @@
 
 #if OSS_SUPPORT
 
+#if defined(HAVE_SYS_SOUNDCARD_H)
 #include <sys/soundcard.h>
+#elif defined(HAVE_LINUX_SOUNDCARD_H)
+#include <linux/soundcard.h>
+#else
+#include <machine/soundcard.h>
+#endif
+
 #include <sys/ioctl.h>
 #include <sys/time.h>
 #include <sys/types.h>
