@@ -249,20 +249,34 @@ new_fluid_winmidi_driver(fluid_settings_t *settings,
 
             if(res == MMSYSERR_NOERROR)
             {
-                FLUID_LOG(FLUID_DBG, "Testing midi device: %s\n", in_caps.szPname);
+                int str_cmp_res;
+#ifdef _UNICODE
+                WCHAR wDevName[MAXPNAMELEN];
+                MultiByteToWideChar(CP_UTF8, 0, dev_name, -1, wDevName, MAXPNAMELEN);
 
-                if(FLUID_STRCASECMP(dev_name, in_caps.szPname) == 0)
+                str_cmp_res = wcsicmp(wDevName, in_caps.szPname);
+#else
+                str_cmp_res = FLUID_STRCASECMP(dev_name, in_caps.szPname);
+#endif
+
+                FLUID_LOG(FLUID_DBG, "Testing midi device \"%s\"", in_caps.szPname);
+
+                if(str_cmp_res == 0)
                 {
-                    FLUID_LOG(FLUID_DBG, "Selected midi device number: %d\n", i);
+                    FLUID_LOG(FLUID_DBG, "Selected midi device number: %u", i);
                     midi_num = i;
                     break;
                 }
             }
+            else
+            {
+                FLUID_LOG(FLUID_DBG, "Error testing midi device %u of %u: %s (error %d)", i, num, fluid_winmidi_input_error(strError, res), res);
+            }
         }
 
         if(midi_num != i)
         {
-            FLUID_LOG(FLUID_ERR, "Device <%s> does not exists", dev_name);
+            FLUID_LOG(FLUID_ERR, "Device \"%s\" does not exists", dev_name);
             return NULL;
         }
     }
