@@ -174,7 +174,7 @@ fluid_file_read_full(fluid_file fp, size_t *length)
         return NULL;
     }
 
-    FLUID_LOG(FLUID_DBG, "File load: Allocating %lu bytes", buflen);
+    FLUID_LOG(FLUID_DBG, "File load: Allocating %lu bytes", (unsigned long)buflen);
     buffer = FLUID_MALLOC(buflen);
 
     if(buffer == NULL)
@@ -187,8 +187,8 @@ fluid_file_read_full(fluid_file fp, size_t *length)
 
     if(n != buflen)
     {
-        FLUID_LOG(FLUID_ERR, "Only read %lu bytes; expected %lu", n,
-                  buflen);
+        FLUID_LOG(FLUID_ERR, "Only read %lu bytes; expected %lu", (unsigned long)n,
+                  (unsigned long)buflen);
         FLUID_FREE(buffer);
         return NULL;
     };
@@ -1717,6 +1717,9 @@ delete_fluid_player(fluid_player_t *player)
 
     fluid_return_if_fail(player != NULL);
 
+    fluid_settings_callback_int(player->synth->settings, "player.reset-synth",
+                                NULL, NULL);
+
     fluid_player_stop(player);
     fluid_player_reset(player);
 
