@@ -679,14 +679,19 @@ DECLARE_FLUID_RVOICE_FUNCTION(fluid_rvoice_mixer_set_samplerate)
     {
         if(mixer->fx[i].chorus)
         {
-            delete_fluid_chorus(mixer->fx[i].chorus);
+            fluid_chorus_samplerate_change(mixer->fx[i].chorus, samplerate);
         }
 
-        mixer->fx[i].chorus = new_fluid_chorus(samplerate);
-
         if(mixer->fx[i].reverb)
         {
             fluid_revmodel_samplerate_change(mixer->fx[i].reverb, samplerate);
+
+            /*
+              fluid_revmodel_samplerate_change() shouldn't fail if the reverb was created
+              with sample_rate_max set to the maximum sample rate indicated in the settings.
+              If this condition isn't respected, the reverb will continue to work but with
+              lost of quality.
+            */
         }
     }
 
@@ -706,7 +711,11 @@ DECLARE_FLUID_RVOICE_FUNCTION(fluid_rvoice_mixer_set_samplerate)
  * @param fx_buf_count number of stereo effect buffers
  */
 fluid_rvoice_mixer_t *
-new_fluid_rvoice_mixer(int buf_count, int fx_buf_count, int fx_units, fluid_real_t sample_rate, fluid_rvoice_eventhandler_t *evthandler, int extra_threads, int prio)
+new_fluid_rvoice_mixer(int buf_count, int fx_buf_count, int fx_units,
+                       fluid_real_t sample_rate_max,
+                       fluid_real_t sample_rate,
+                       fluid_rvoice_eventhandler_t *evthandler,
+                       int extra_threads, int prio)
 {
     int i;
     fluid_rvoice_mixer_t *mixer = FLUID_NEW(fluid_rvoice_mixer_t);
@@ -730,12 +739,13 @@ new_fluid_rvoice_mixer(int buf_count, int fx_buf_count, int fx_units, fluid_real
         FLUID_LOG(FLUID_ERR, "Out of memory");
         goto error_recovery;
     }
-    
+
     FLUID_MEMSET(mixer->fx, 0, fx_units * sizeof(*mixer->fx));
-    
+
     for(i = 0; i < fx_units; i++)
     {
-        mixer->fx[i].reverb = new_fluid_revmodel(sample_rate);
+        /* create reverb and chorus units */
+        mixer->fx[i].reverb = new_fluid_revmodel(sample_rate_max, sample_rate);
         mixer->fx[i].chorus = new_fluid_chorus(sample_rate);
 
         if(mixer->fx[i].reverb == NULL || mixer->fx[i].chorus == NULL)
@@ -770,7 +780,7 @@ new_fluid_rvoice_mixer(int buf_count, int fx_buf_count, int fx_units, fluid_real
 #endif
 
     return mixer;
-    
+
 error_recovery:
     delete_fluid_rvoice_mixer(mixer);
     return NULL;
@@ -1268,27 +1278,33 @@ fluid_render_loop_multithread(fluid_rvoice_mixer_t *mixer, int current_blockcoun
 static void delete_rvoice_mixer_threads(fluid_rvoice_mixer_t *mixer)
 {
     int i;
-    fluid_atomic_int_set(&mixer->threads_should_terminate, 1);
-    // Signal threads to wake up
-    fluid_cond_mutex_lock(mixer->wakeup_threads_m);
 
-    for(i = 0; i < mixer->thread_count; i++)
+    // if no threads have been created yet (e.g. because a previous error prevented creation of threads
+    // mutexes and condition variables), skip terminating threads
+    if(mixer->thread_count != 0)
     {
-        fluid_atomic_int_set(&mixer->threads[i].ready, THREAD_BUF_TERMINATE);
-    }
+        fluid_atomic_int_set(&mixer->threads_should_terminate, 1);
+        // Signal threads to wake up
+        fluid_cond_mutex_lock(mixer->wakeup_threads_m);
 
-    fluid_cond_broadcast(mixer->wakeup_threads);
-    fluid_cond_mutex_unlock(mixer->wakeup_threads_m);
-
-    for(i = 0; i < mixer->thread_count; i++)
-    {
-        if(mixer->threads[i].thread)
+        for(i = 0; i < mixer->thread_count; i++)
         {
-            fluid_thread_join(mixer->threads[i].thread);
-            delete_fluid_thread(mixer->threads[i].thread);
+            fluid_atomic_int_set(&mixer->threads[i].ready, THREAD_BUF_TERMINATE);
         }
 
-        fluid_mixer_buffers_free(&mixer->threads[i]);
+        fluid_cond_broadcast(mixer->wakeup_threads);
+        fluid_cond_mutex_unlock(mixer->wakeup_threads_m);
+
+        for(i = 0; i < mixer->thread_count; i++)
+        {
+            if(mixer->threads[i].thread)
+            {
+                fluid_thread_join(mixer->threads[i].thread);
+                delete_fluid_thread(mixer->threads[i].thread);
+            }
+
+            fluid_mixer_buffers_free(&mixer->threads[i]);
+        }
     }
 
     FLUID_FREE(mixer->threads);
